# APIBox

API tools all in one, for dedicated web developers

## TODO

- [ ] specify json schema for check input parameters & output data
- [ ] specify python/js code for assertion
- [ ] support ansible playbook style module using, for both request and response lifecycle handling
